@@ -30,12 +30,7 @@ func (c *brokerCommand) newListCommand() *cobra.Command {
 }
 
 func (c *brokerCommand) list(cmd *cobra.Command, _ []string) error {
-	restClient, restContext, err := initKafkaRest(c.AuthenticatedCLICommand, cmd)
-	if err != nil {
-		return err
-	}
-
-	clusterId, err := getClusterIdForRestRequests(restClient, restContext)
+	restClient, restContext, clusterId, err := initKafkaRest(c.AuthenticatedCLICommand, cmd)
 	if err != nil {
 		return err
 	}
