@@ -13,9 +13,9 @@ import (
 
 func (c *Command) newKafkaTopicDeleteCommand() *cobra.Command {
 	cmd := &cobra.Command{
-		Use:   "delete <topic>",
-		Short: "Delete a Kafka topic.",
-		Args:  cobra.ExactArgs(1),
+		Use:   "delete <topic-1> [topic-2] ... [topic-n]",
+		Short: "Delete one or more Kafka topics.",
+		Args:  cobra.MinimumNArgs(1),
 		RunE:  c.kafkaTopicDelete,
 		Example: examples.BuildExampleString(
 			examples.Example{
@@ -36,5 +36,5 @@ func (c *Command) kafkaTopicDelete(cmd *cobra.Command, args []string) error {
 		return errors.NewErrorWithSuggestions(err.Error(), kafkaRestNotReadySuggestion)
 	}
 
-	return kafka.DeleteTopic(cmd, restClient, context.Background(), args[0], clusterId)
+	return kafka.DeleteTopic(cmd, restClient, context.Background(), args, clusterId)
 }
